@@ -15,7 +15,7 @@
 #  limitations under the License.
 
 import re
-from calculate.lib.format.samba import samba
+from .samba import samba
 
 
 class compiz(samba):
